@@ -40,6 +40,7 @@
 #include <Lum/OS/Color.h>
 
 #include <Lum/Manager/Display.h>
+#include <Lum/Manager/FileSystem.h>
 
 #include <Lum/Application.h>
 #include <Lum/Label.h>
@@ -135,7 +136,7 @@ public:
             int x, int y, size_t width, size_t height) const
   {
     DiskInfo     diskInfo=dynamic_cast<const DiskInfoModel*>(GetModel())->GetEntry(GetRow());
-    std::wstring sizeText=Lum::Base::ByteSizeToWString(diskInfo.avail*diskInfo.unit*1024)+L" free";
+    std::wstring sizeText=Lum::Base::ByteSizeToWString(diskInfo.avail*diskInfo.unit*1024);
     size_t       sizeTextWidth=GetFont()->StringWidth(sizeText);
 
     draw->PushFont(GetFont());
@@ -179,7 +180,7 @@ private:
 
   Lum::Model::ActionRef              showMap;
 
-  Lum::Model::IntRef                 refreshTime;
+  Lum::Model::ULongRef               refreshTime;
   Lum::Model::ActionRef              timer;
 
   Lum::Table                         *table;
@@ -201,7 +202,7 @@ public:
   MainWindow()
   : about(new Lum::Model::Action()),
     showMap(new Lum::Model::Action()),
-    refreshTime(new Lum::Model::Int(15)),
+    refreshTime(new Lum::Model::ULong(15)),
     timer(new Lum::Model::Action()),
     selection(new Lum::Model::SingleLineSelection),
     tableModel(new DiskInfoModel()),
@@ -212,11 +213,15 @@ public:
     total(new Lum::Model::String()),
     data(new Lum::Model::DoubleDataStream())
   {
+    GetWindow()->SetScreenOrientationHint(Lum::OS::Window::screenOrientationBothSupported);
+
+    tableModel->SetEmptyText(_(L"NO_PARTITIONS",L"(No partitions found)"));
+
     data->SetNotificationMode(Lum::Model::DoubleDataStream::notifyExplicit);
     data->SetChannels(3);
 
     scanTask.SetParent(this);
-    scanTask.SetCaption(L"Scanning directory...");
+    scanTask.SetCaption(_(L"SCANNING",L"Scanning directory..."));
 
     Observe(about);
     Observe(showMap);
@@ -237,43 +242,85 @@ public:
     Lum::PercentPie       *percent;
     Lum::Model::HeaderRef headerModel;
 
-    tableModel->SetEmptyText(L"(No partitions found)");
+    if (Lum::OS::display->IsLandscape()) {
+      panel=Lum::VPanel::Create(true,true);
 
-    panel=Lum::VPanel::Create(true,true);
-    panel->SetWidth(Lum::Base::Size::workHRel,20);
-    panel->SetHeight(Lum::Base::Size::workVRel,40);
+      panel2=Lum::HPanel::Create(true,false);
+      panel2->Add(Lum::Label::Create()
+                  ->AddLabel(_(L"LABEL_DEVICE",L"Device:"),
+                             GetTextValueLeft(device))
+                  ->AddLabel(_(L"LABEL_DIRECTORY",L"Directory:"),
+                             GetTextValueLeft(dir))
+                  ->AddLabel(_(L"LABEL_SIZE",L"Size:"),
+                             GetTextValueRight(total))
+                  ->AddLabel(_(L"LABEL_USED",L"Used:"),
+                             GetTextValueRight(used))
+                  ->AddLabel(_(L"LABEL_FREE",L"Free:"),
+                             GetTextValueRight(free)));
+      panel2->AddSpace(true);
 
-    panel2=Lum::HPanel::Create(true,false);
-    panel2->Add(Lum::Label::Create()
-                ->AddLabel(L"Device:",GetTextValueLeft(device))
-                ->AddLabel(L"Directory:",GetTextValueLeft(dir))
-                ->AddLabel(L"Size:",GetTextValueRight(total))
-                ->AddLabel(L"Used:",GetTextValueRight(used))
-                ->AddLabel(L"Free:",GetTextValueRight(free)));
-    panel2->AddSpace(true);
+      percent=new Lum::PercentPie();
+      percent->SetModel(data);
+      panel2->Add(percent);
 
-    percent=new Lum::PercentPie();
-    percent->SetModel(data);
-    panel2->Add(percent);
+      panel->Add(panel2);
+      panel->AddSpace();
 
-    panel->Add(panel2);
-    panel->AddSpace();
+      headerModel=new Lum::Model::HeaderImpl();
+      headerModel->AddColumn(L"Dir",Lum::Base::Size::stdCharWidth,25,true);
 
-    headerModel=new Lum::Model::HeaderImpl();
-    headerModel->AddColumn(L"Dir",Lum::Base::Size::stdCharWidth,25,true);
+      table=new Lum::Table();
+      table->SetHeight(Lum::Base::Size::workVRel,20);
+      table->SetFlex(true,true);
+      table->SetModel(tableModel);
+      table->SetHeaderModel(headerModel);
+      table->SetSelection(selection);
+      table->SetDoubleClickAction(showMap);
+      table->SetShowHeader(false);
+      table->SetPainter(new DiskInfoModelPainter());
+      table->GetTableView()->SetAutoFitColumns(true);
+      panel->Add(table);
 
-    table=new Lum::Table();
-    table->SetFlex(true,true);
-    table->SetModel(tableModel);
-    table->SetHeaderModel(headerModel);
-    table->SetSelection(selection);
-    table->SetDoubleClickAction(showMap);
-    table->SetShowHeader(false);
-    table->SetPainter(new DiskInfoModelPainter());
-    table->GetTableView()->SetAutoFitColumns(true);
-    panel->Add(table);
+      SetMain(panel);
+    }
+    else {
+      panel=Lum::VPanel::Create(true,true);
 
-    SetMain(panel);
+      percent=new Lum::PercentPie();
+      percent->SetModel(data);
+      panel->Add(percent);
+
+      panel->AddSpace();
+
+      panel2=Lum::HPanel::Create(true,false);
+      panel2->Add(Lum::Label::Create()
+                  ->AddLabel(L"Device:",GetTextValueLeft(device))
+                  ->AddLabel(L"Directory:",GetTextValueLeft(dir))
+                  ->AddLabel(L"Size:",GetTextValueRight(total))
+                  ->AddLabel(L"Used:",GetTextValueRight(used))
+                  ->AddLabel(L"Free:",GetTextValueRight(free)));
+      panel2->AddSpace(true);
+      panel->Add(panel2);
+
+      panel->AddSpace();
+
+      headerModel=new Lum::Model::HeaderImpl();
+      headerModel->AddColumn(L"Dir",Lum::Base::Size::stdCharWidth,25,true);
+
+      table=new Lum::Table();
+      table->SetMinHeight(Lum::Base::Size::workVRel,20);
+      table->SetFlex(true,true);
+      table->SetModel(tableModel);
+      table->SetHeaderModel(headerModel);
+      table->SetSelection(selection);
+      table->SetDoubleClickAction(showMap);
+      table->SetShowHeader(false);
+      table->SetPainter(new DiskInfoModelPainter());
+      table->GetTableView()->SetAutoFitColumns(true);
+      panel->Add(table);
+
+      SetMain(panel);
+    }
 
     Lum::Def::Menu *menu=Lum::Def::Menu::Create();
 
@@ -281,6 +328,12 @@ public:
       ->GroupProject()
         ->ActionQuit(GetClosedAction())
       ->End()
+      ->GroupEdit()
+        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_OPEN_MAP",L"_Treemap"))
+                                  .SetShortcut(Lum::OS::qualifierControl,L"m"),
+                                  showMap)
+                 .SetOpensDialog())
+      ->End()
       ->GroupHelp()
         //->AddMenuItemAction(_ld(menuHelpHelp),NULL)
         ->ActionAbout(about)
@@ -495,12 +548,12 @@ public:
   bool Initialize()
   {
 #if defined(APP_DATADIR)
-    Lum::Base::Path::SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
+    Lum::Manager::FileSystem::Instance()->SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
 #endif
 
     info.SetProgram(Lum::Base::StringToWString(PACKAGE_NAME));
     info.SetVersion(Lum::Base::StringToWString(PACKAGE_VERSION));
-    info.SetDescription(_(L"ABOUT_DESC",L"Show usage of all available disks"));
+    info.SetDescription(_(L"ABOUT_DESC",L"Shows usage of all available disks"));
     info.SetAuthor(L"Tim Teulings");
     info.SetContact(L"Tim Teulings <tim@teulings.org>");
     info.SetCopyright(L"(c) 2004, Tim Teulings");
